        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>36</strong> miembros: 28 <strong>control</strong><br>0,3,6,8,9,10,12,13,14,16,19,20,21,23,32,33,34,35,36,37,38,40,41,42,43,44,47,49';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 13 <br>1,2,5,7,15,18,22,28,29,30,46,48,50';}
       if(rr==4 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 10 <br>4,11,17,24,25,26,27,31,39,45';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>36</strong> miembros: 28 <strong>control</strong><br>0,3,6,8,9,10,12,13,14,16,19,20,21,23,32,33,34,35,36,37,38,40,41,42,43,44,47,49';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 13 <br>1,2,5,7,15,18,22,28,29,30,46,48,50';}
       if(rr==23 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 10 <br>4,11,17,24,25,26,27,31,39,45';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>36</strong> miembros: 28 <strong>control</strong><br>0,3,6,8,9,10,12,13,14,16,19,20,21,23,32,33,34,35,36,37,38,40,41,42,43,44,47,49';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 13 <br>1,2,5,7,15,18,22,28,29,30,46,48,50';}
       if(rr==25 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 10 <br>4,11,17,24,25,26,27,31,39,45';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>36</strong> miembros: 28 <strong>control</strong><br>0,3,6,8,9,10,12,13,14,16,19,20,21,23,32,33,34,35,36,37,38,40,41,42,43,44,47,49';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 13 <br>1,2,5,7,15,18,22,28,29,30,46,48,50';}
       if(rr==26 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 10 <br>4,11,17,24,25,26,27,31,39,45';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>36</strong> miembros: 28 <strong>control</strong><br>0,3,6,8,9,10,12,13,14,16,19,20,21,23,32,33,34,35,36,37,38,40,41,42,43,44,47,49';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 13 <br>1,2,5,7,15,18,22,28,29,30,46,48,50';}
       if(rr==27 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 10 <br>4,11,17,24,25,26,27,31,39,45';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>36</strong> miembros: 28 <strong>control</strong><br>0,3,6,8,9,10,12,13,14,16,19,20,21,23,32,33,34,35,36,37,38,40,41,42,43,44,47,49';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 13 <br>1,2,5,7,15,18,22,28,29,30,46,48,50';}
       if(rr==28 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260505 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 10 <br>4,11,17,24,25,26,27,31,39,45';}
}
